==> structurizr-dsl-1.20.0-sources.jar: com/structurizr/dsl/StructurizrDslTokens.java <==
package com.structurizr.dsl;

/**
 * Main DSL parser class - forms the API for using the parser.
 */
class StructurizrDslTokens {

    static final String ASSIGNMENT_OPERATOR_TOKEN = "=";

    static final String CUSTOM_ELEMENT_TOKEN = "element";
    static final String PERSON_TOKEN = "person";
    static final String SOFTWARE_SYSTEM_TOKEN = "softwareSystem";
    static final String RELATIONSHIP_TOKEN = "->";
    static final String CONTAINER_TOKEN = "container";
    static final String COMPONENT_TOKEN = "component";
    static final String GROUP_TOKEN = "group";
    static final String NAME_TOKEN = "name";
    static final String DESCRIPTION_TOKEN = "description";
    static final String TECHNOLOGY_TOKEN = "technology";
    static final String INSTANCES_TOKEN = "instances";
    static final String TAGS_TOKEN = "tags";
    static final String URL_TOKEN = "url";
    static final String PROPERTIES_TOKEN = "properties";
    static final String PERSPECTIVES_TOKEN = "perspectives";
    static final String WORKSPACE_TOKEN = "workspace";
    static final String EXTENDS_TOKEN = "extends";
    static final String MODEL_TOKEN = "model";
    static final String VIEWS_TOKEN = "views";
    static final String ENTERPRISE_TOKEN = "enterprise";
    static final String DEPLOYMENT_ENVIRONMENT_TOKEN = "deploymentEnvironment";
    static final String DEPLOYMENT_GROUP_TOKEN = "deploymentGroup";
    static final String DEPLOYMENT_NODE_TOKEN = "deploymentNode";
    static final String INFRASTRUCTURE_NODE_TOKEN = "infrastructureNode";
    static final String SOFTWARE_SYSTEM_INSTANCE_TOKEN = "softwareSystemInstance";
    static final String CONTAINER_INSTANCE_TOKEN = "containerInstance";
    static final String HEALTH_CHECK_TOKEN = "healthCheck";
    static final String CUSTOM_VIEW_TOKEN = "custom";
    static final String SYSTEM_LANDSCAPE_VIEW_TOKEN = "systemLandscape";
    static final String SYSTEM_CONTEXT_VIEW_TOKEN = "systemContext";
    static final String CONTAINER_VIEW_TOKEN = "container";
    static final String COMPONENT_VIEW_TOKEN = "component";
    static final String DYNAMIC_VIEW_TOKEN = "dynamic";
    static final String DEPLOYMENT_VIEW_TOKEN = "deployment";
    static final String FILTERED_VIEW_TOKEN = "filtered";
    static final String INCLUDE_IN_VIEW_TOKEN = "include";
    static final String EXCLUDE_IN_VIEW_TOKEN = "exclude";
    static final String ANIMATION_IN_VIEW_TOKEN = "animation";
    static final String ANIMATION_STEP_IN_VIEW_TOKEN = "animationStep";
    static final String AUTOLAYOUT_VIEW_TOKEN = "autolayout";
    static final String VIEW_TITLE_TOKEN = "title";
    static final String VIEW_DESCRIPTION_TOKEN = "description";
    static final String STYLES_TOKEN = "styles";
    static final String BRANDING_TOKEN = "branding";
    static final String BRANDING_LOGO_TOKEN = "logo";
    static final String BRANDING_FONT_TOKEN = "font";
    static final String ELEMENT_STYLE_TOKEN = "element";
    static final String ELEMENT_STYLE_SHAPE_TOKEN = "shape";
    static final String ELEMENT_STYLE_BACKGROUND_TOKEN = "background";
    static final String ELEMENT_STYLE_STROKE_TOKEN = "stroke";
    static final String ELEMENT_STYLE_COLOUR_TOKEN = "colour";
    static final String ELEMENT_STYLE_COLOR_TOKEN = "color";
    static final String ELEMENT_STYLE_ICON_TOKEN = "icon";
    static final String ELEMENT_STYLE_OPACITY_TOKEN = "opacity";
    static final String ELEMENT_STYLE_BORDER_TOKEN = "border";
    static final String ELEMENT_STYLE_FONT_SIZE_TOKEN = "fontSize";
    static final String ELEMENT_STYLE_WIDTH_TOKEN = "width";
    static final String ELEMENT_STYLE_HEIGHT_TOKEN = "height";
    static final String ELEMENT_STYLE_METADATA_TOKEN = "metadata";
    static final String ELEMENT_STYLE_DESCRIPTION_TOKEN = "description";
    static final String RELATIONSHIP_STYLE_TOKEN = "relationship";
    static final String RELATIONSHIP_STYLE_THICKNESS_TOKEN = "thickness";
    static final String RELATIONSHIP_STYLE_COLOUR_TOKEN = "colour";
    static final String RELATIONSHIP_STYLE_COLOR_TOKEN = "color";
    static final String RELATIONSHIP_STYLE_DASHED_TOKEN = "dashed";
    static final String RELATIONSHIP_STYLE_OPACITY_TOKEN = "opacity";
    static final String RELATIONSHIP_STYLE_ROUTING_TOKEN = "routing";
    static final String RELATIONSHIP_STYLE_LINE_STYLE_TOKEN = "style";
    static final String RELATIONSHIP_STYLE_FONT_SIZE_TOKEN = "fontSize";
    static final String RELATIONSHIP_STYLE_WIDTH_TOKEN = "width";
    static final String RELATIONSHIP_STYLE_POSITION_TOKEN = "position";
    static final String THEME_TOKEN = "theme";
    static final String THEMES_TOKEN = "themes";
    static final String CONFIGURATION_TOKEN = "configuration";
    static final String TERMINOLOGY_TOKEN = "terminology";
    static final String TERMINOLOGY_RELATIONSHIP_TOKEN = "relationship";
    static final String USERS_TOKEN = "users";
    static final String THIS_TOKEN = "this";

    static final String INCLUDE_FILE_TOKEN = "!include";
    static final String DOCS_TOKEN = "!docs";
    static final String ADRS_TOKEN = "!adrs";
    static final String CONSTANT_TOKEN = "!constant";
    static final String IDENTIFIERS_TOKEN = "!identifiers";
    static final String IMPLIED_RELATIONSHIPS_TOKEN = "!impliedRelationships";
    static final String REF_TOKEN = "!ref";
    static final String PLUGIN_TOKEN = "!plugin";
    static final String SCRIPT_TOKEN = "!script";

}

==> structurizr-dsl-1.29.0-sources.jar: com/structurizr/dsl/StructurizrDslTokens.java <==
package com.structurizr.dsl;

/**
 * Main DSL parser class - forms the API for using the parser.
 */
class StructurizrDslTokens {

    static final String ASSIGNMENT_OPERATOR_TOKEN = "=";

    static final String CUSTOM_ELEMENT_TOKEN = "element";
    static final String PERSON_TOKEN = "person";
    static final String SOFTWARE_SYSTEM_TOKEN = "softwareSystem";
    static final String RELATIONSHIP_TOKEN = "->";
    static final String CONTAINER_TOKEN = "container";
    static final String COMPONENT_TOKEN = "component";
    static final String GROUP_TOKEN = "group";
    static final String NAME_TOKEN = "name";
    static final String DESCRIPTION_TOKEN = "description";
    static final String TECHNOLOGY_TOKEN = "technology";
    static final String INSTANCES_TOKEN = "instances";
    static final String TAGS_TOKEN = "tags";
    static final String URL_TOKEN = "url";
    static final String PROPERTIES_TOKEN = "properties";
    static final String PERSPECTIVES_TOKEN = "perspectives";
    static final String WORKSPACE_TOKEN = "workspace";
    static final String EXTENDS_TOKEN = "extends";
    static final String MODEL_TOKEN = "model";
    static final String VIEWS_TOKEN = "views";
    static final String ENTERPRISE_TOKEN = "enterprise";
    static final String DEPLOYMENT_ENVIRONMENT_TOKEN = "deploymentEnvironment";
    static final String DEPLOYMENT_GROUP_TOKEN = "deploymentGroup";
    static final String DEPLOYMENT_NODE_TOKEN = "deploymentNode";
    static final String INFRASTRUCTURE_NODE_TOKEN = "infrastructureNode";
    static final String SOFTWARE_SYSTEM_INSTANCE_TOKEN = "softwareSystemInstance";
    static final String CONTAINER_INSTANCE_TOKEN = "containerInstance";
    static final String HEALTH_CHECK_TOKEN = "healthCheck";
    static final String CUSTOM_VIEW_TOKEN = "custom";
    static final String SYSTEM_LANDSCAPE_VIEW_TOKEN = "systemLandscape";
    static final String SYSTEM_CONTEXT_VIEW_TOKEN = "systemContext";
    static final String CONTAINER_VIEW_TOKEN = "container";
    static final String COMPONENT_VIEW_TOKEN = "component";
    static final String DYNAMIC_VIEW_TOKEN = "dynamic";
    static final String DEPLOYMENT_VIEW_TOKEN = "deployment";
    static final String FILTERED_VIEW_TOKEN = "filtered";
    static final String IMAGE_VIEW_TOKEN = "image";
    static final String INCLUDE_IN_VIEW_TOKEN = "include";
    static final String EXCLUDE_IN_VIEW_TOKEN = "exclude";
    static final String ANIMATION_IN_VIEW_TOKEN = "animation";
    static final String ANIMATION_STEP_IN_VIEW_TOKEN = "animationStep";
    static final String AUTOLAYOUT_VIEW_TOKEN = "autolayout";
    static final String DEFAULT_VIEW_TOKEN = "default";
    static final String VIEW_TITLE_TOKEN = "title";
    static final String VIEW_DESCRIPTION_TOKEN = "description";
    static final String PLANTUML_TOKEN = "plantuml";
    static final String MERMAID_TOKEN = "mermaid";
    static final String KROKI_TOKEN = "kroki";
    static final String IMAGE_TOKEN = "image";
    static final String STYLES_TOKEN = "styles";
    static final String BRANDING_TOKEN = "branding";
    static final String BRANDING_LOGO_TOKEN = "logo";
    static final String BRANDING_FONT_TOKEN = "font";
    static final String ELEMENT_STYLE_TOKEN = "element";
    static final String ELEMENT_STYLE_SHAPE_TOKEN = "shape";
    static final String ELEMENT_STYLE_BACKGROUND_TOKEN = "background";
    static final String ELEMENT_STYLE_STROKE_TOKEN = "stroke";
    static final String ELEMENT_STYLE_STROKE_WIDTH_TOKEN = "strokeWidth";
    static final String ELEMENT_STYLE_COLOUR_TOKEN = "colour";
    static final String ELEMENT_STYLE_COLOR_TOKEN = "color";
    static final String ELEMENT_STYLE_ICON_TOKEN = "icon";
    static final String ELEMENT_STYLE_OPACITY_TOKEN = "opacity";
    static final String ELEMENT_STYLE_BORDER_TOKEN = "border";
    static final String ELEMENT_STYLE_FONT_SIZE_TOKEN = "fontSize";
    static final String ELEMENT_STYLE_WIDTH_TOKEN = "width";
    static final String ELEMENT_STYLE_HEIGHT_TOKEN = "height";
    static final String ELEMENT_STYLE_METADATA_TOKEN = "metadata";
    static final String ELEMENT_STYLE_DESCRIPTION_TOKEN = "description";
    static final String RELATIONSHIP_STYLE_TOKEN = "relationship";
    static final String RELATIONSHIP_STYLE_THICKNESS_TOKEN = "thickness";
    static final String RELATIONSHIP_STYLE_COLOUR_TOKEN = "colour";
    static final String RELATIONSHIP_STYLE_COLOR_TOKEN = "color";
    static final String RELATIONSHIP_STYLE_DASHED_TOKEN = "dashed";
    static final String RELATIONSHIP_STYLE_OPACITY_TOKEN = "opacity";
    static final String RELATIONSHIP_STYLE_ROUTING_TOKEN = "routing";
    static final String RELATIONSHIP_STYLE_LINE_STYLE_TOKEN = "style";
    static final String RELATIONSHIP_STYLE_FONT_SIZE_TOKEN = "fontSize";
    static final String RELATIONSHIP_STYLE_WIDTH_TOKEN = "width";
    static final String RELATIONSHIP_STYLE_POSITION_TOKEN = "position";
    static final String THEME_TOKEN = "theme";
    static final String THEMES_TOKEN = "themes";
    static final String CONFIGURATION_TOKEN = "configuration";
    static final String TERMINOLOGY_TOKEN = "terminology";
    static final String TERMINOLOGY_RELATIONSHIP_TOKEN = "relationship";
    static final String USERS_TOKEN = "users";
    static final String THIS_TOKEN = "this";

    static final String INCLUDE_FILE_TOKEN = "!include";
    static final String DOCS_TOKEN = "!docs";
    static final String ADRS_TOKEN = "!adrs";
    static final String CONSTANT_TOKEN = "!constant";
    static final String IDENTIFIERS_TOKEN = "!identifiers";
    static final String IMPLIED_RELATIONSHIPS_TOKEN = "!impliedRelationships";
    static final String REF_TOKEN = "!ref";
    static final String PLUGIN_TOKEN = "!plugin";
    static final String SCRIPT_TOKEN = "!script";

}
